@@ -29,7 +29,7 @@ extern char DHCPD_CONF_BUF[1024];
 #include "add_conf_button_clicked.h"
 #include "cancel_add_conf_button_clicked.h"
 
-void add_conf_dialog(struct gdhcpd_widgets *widgets)
+void add_conf_dialog(struct w *widgets)
 {
     gchar *utf8=NULL;
     GtkTextBuffer *text_buffer;
