@@ -35,7 +35,7 @@ extern char DHCPD_CONF_BUF[1024];
 
 
 
-void add_host(struct gdhcpd_widgets *widgets)
+void add_host(struct w *widgets)
 {
     FILE *fp;
     long conf_size;
@@ -86,6 +86,8 @@ void add_host(struct gdhcpd_widgets *widgets)
     line = allocate(conf_size+1);
 
     host_line = g_strdup_printf("host %s {\n", hostname);
+
+    if( conf_size > 1 )
     while(fgets(line, conf_size, fp)!=NULL)
     {
 	if( !strcmp(line, host_line) && ! strstr(line, "#") )
