@@ -33,7 +33,7 @@ extern char DHCPD_CONF_BUF[1024];
 
 
 
-void add_scope(struct gdhcpd_widgets *widgets)
+void add_scope(struct w *widgets)
 {
     FILE *fp;
     char *line;
@@ -81,6 +81,8 @@ void add_scope(struct gdhcpd_widgets *widgets)
     line = allocate(conf_size+1);
 				    
     scope_line = g_strdup_printf("subnet %s netmask %s {\n", subnet, netmask);
+
+    if( conf_size > 1 )
     while(fgets(line, conf_size, fp)!=NULL)
     {
         if( !strcmp(line, scope_line) && ! strstr(line, "#") )
@@ -102,16 +104,29 @@ void add_scope(struct gdhcpd_widgets *widgets)
     }
 
 
-    /* Add the scope */
+    /* Add the scope, FIXME: add it before other scopes */
     if((fp=fopen(DHCPD_CONF_BUF, "a"))==NULL)
     {
         printf("Couldnt write dhcpd.conf here: %s\n", DHCPD_CONF_BUF);
         return;
     }
 
-    scope = g_strdup_printf("\nsubnet %s netmask %s {\n    interface %s;\n}\n", subnet, netmask, nic);
+    /* Also adds some standard values such as time etc */
+    scope = g_strconcat("\nsubnet ", subnet, " netmask ", netmask," {\n",
+    "   interface ", nic,";\n",
+    
+    "	option subnet-mask ", netmask, ";\n",
+
+    "	default-lease-time 6000;\n",
+    "	max-lease-time 7200;\n",
+    "	option time-offset -3600;\n",
+    
+    "}\n",
+    NULL);
+
     fputs(scope, fp);    
     fclose(fp);    
+
     g_free(scope);
 
     /* FIXME set this as the selected scope (now we have the first scope as selected) */
