@@ -24,6 +24,7 @@
 #include <stdlib.h>
 #include "widgets.h"
 #include "gettext.h"
+#include "allocate.h"
 #include "show_info.h"
 #include "get_ranges_from_current_scope.h"
 #include "delete_scope.h"
@@ -32,29 +33,51 @@
 #include "set_num_ranges.h"
 #include "populate_ranges.h"
 #include "populate_scope_settings.h"
+#include "failover_functions.h"
 #include "reread_conf.h"
+
+extern char global_netmask[1024];
+extern char global_subnet[1024];
+extern char global_nic[1024];
+
 extern char DHCPD_CONF_BUF[1024];
 
 
 
-void apply_scope_settings(struct gdhcpd_widgets *widgets)
+void apply_scope_settings(struct w *widgets)
 {
     FILE *fp;
-    gchar *new_scope_begin, *new_scope_end;
+    long conf_size;
+    char *line, *new_conf;
+    gchar *new_scope_begin, *new_scope_end, *failover_decl;
+    gchar *nic, *subnet, *netmask;
     G_CONST_RETURN gchar *change_nic, *change_subnet, *change_netmask;
     gchar *setting=NULL, *info;
     char *ranges;
-    int new_scope_def = 0;
+    int once = 0, new_scope_def = 0;
 
     change_nic = gtk_entry_get_text(GTK_ENTRY(widgets->scope_set_entry[0]));
     change_subnet = gtk_entry_get_text(GTK_ENTRY(widgets->scope_set_entry[1]));
     change_netmask = gtk_entry_get_text(GTK_ENTRY(widgets->scope_set_entry[2]));
 
+    subnet = g_strdup_printf("%s", global_subnet);
+    netmask = g_strdup_printf("%s", global_netmask);
+    nic = g_strdup_printf("%s", global_nic);
+
+    /* Save any failover declaration so we can put it back later */
+    failover_decl = get_failover(nic, subnet, netmask, "return-entire-declaration");
+
+    g_free(nic);
+    g_free(subnet);
+    g_free(netmask);
+
+
     if( strlen(change_nic) < 2 )
     {
         info = g_strdup_printf(_("The name of the network card is too short, the scope was not changed.\n"));
         show_info(info);
         g_free(info);
+	g_free(failover_decl);
 	return;
     }
     if( strlen(change_subnet) < 7 )
@@ -62,6 +85,7 @@ void apply_scope_settings(struct gdhcpd_widgets *widgets)
         info = g_strdup_printf(_("The network address is too short, the scope was not changed.\n"));
         show_info(info);
         g_free(info);
+	g_free(failover_decl);
 	return;
     }
     if( strlen(change_netmask) < 7 )
@@ -69,16 +93,21 @@ void apply_scope_settings(struct gdhcpd_widgets *widgets)
         info = g_strdup_printf(_("The subnet mask is too short, the scope was not changed.\n"));
         show_info(info);
         g_free(info);
+	g_free(failover_decl);
 	return;
     }
 
     /* Only update the scope treeview if the scope defs differs */
     if( strcmp(change_nic, global_nic) || strcmp(change_subnet, global_subnet) 
-     || strcmp(change_netmask, global_netmask) )
-      new_scope_def=1;
+    || strcmp(change_netmask, global_netmask) )
+      new_scope_def = 1;
 
+
+
+    /* Save the ranges so we can put them back (Includes pool { declaration) */
     ranges = get_ranges_from_current_scope();
 
+
     new_scope_begin = g_strdup_printf("subnet %s netmask %s {\n    interface %s;\n", 
 								      change_subnet,
 							              change_netmask,
@@ -95,6 +124,9 @@ void apply_scope_settings(struct gdhcpd_widgets *widgets)
         printf("Could not open dhcpd.conf here: %s\n", DHCPD_CONF_BUF);
 	g_free(new_scope_begin);
 	g_free(new_scope_end);
+	
+	if( failover_decl!=NULL )
+	  g_free(failover_decl);
         return;
     }
     
@@ -219,11 +251,65 @@ void apply_scope_settings(struct gdhcpd_widgets *widgets)
     g_free(new_scope_begin);
     g_free(new_scope_end);
 
-    /* Change the globals to new nic sub netmask if any */
+    /* Change the globals to new nic, subnet and netmask if any */
     sprintf(global_nic, "%s", change_nic);
     sprintf(global_subnet, "%s", change_subnet);
     sprintf(global_netmask, "%s", change_netmask);
 
+    
+    /* Insert the saved failover declaration after any global values but
+       before scope declarations or other failovers */
+    if((fp=fopen(DHCPD_CONF_BUF, "r"))==NULL)
+    {
+        printf("Could not open dhcpd.conf here: %s\n", DHCPD_CONF_BUF);
+	g_free(failover_decl);
+        return;
+    }
+    fseek(fp, 0, SEEK_END);
+    conf_size = ftell(fp);
+
+    rewind(fp);
+    
+    line = allocate(conf_size+1);        
+    new_conf = allocate(conf_size+4096+1); /* 4096 for the added failover decl */
+
+
+    /* Put the failover back */
+    while(fgets(line, conf_size, fp)!=NULL)    
+    {
+	if( (strstr(line, "failover peer") || strstr(line, "subnet")) 
+	&& strstr(line, "{") && ! once )
+	{
+	    once = 1;
+
+	    if( failover_decl!=NULL )
+	      strcat(new_conf, failover_decl);
+
+	    strcat(new_conf, line);
+	}
+	else
+	  strcat(new_conf, line);
+    }
+    fclose(fp);
+    free(line);
+
+    if( failover_decl!=NULL )
+      g_free(failover_decl);
+
+
+    /* Write the new file */
+    if((fp=fopen(DHCPD_CONF_BUF, "w+"))==NULL)
+    {
+        printf("Could not write dhcpd.conf here: %s\n", DHCPD_CONF_BUF);
+	free(new_conf);
+        return;
+    }
+    fputs(new_conf, fp);
+    fclose(fp);    
+
+    free(new_conf);
+
+
     /* Only update the scope settings if the scope defs differs */
     if( new_scope_def )
     {
