@@ -1,8 +1,8 @@
 #ifndef GDHCPD_cancel_add_conf_button_clicked_H
 #   define GDHCPD_cancel_add_conf_button_clicked_H
 
-extern struct gdhcpd_widgets *widgets;
+extern struct w *widgets;
 
-void cancel_add_conf_button_clicked(struct gdhcpd_widgets *widgets);
+void cancel_add_conf_button_clicked(struct w *widgets);
 
 #endif
