@@ -25,7 +25,7 @@
 #include "gettext.h"
 
 
-void clear_ptr_array(struct gdhcpd_widgets *widgets)
+void clear_ptr_array(struct w *widgets)
 {
     g_ptr_array_free(widgets->ranges_hbox_array, TRUE);
     g_ptr_array_free(widgets->ranges_from_entry_array, TRUE);
