@@ -28,7 +28,7 @@
 #include "make_settings_entries.h"
  
 
-void create_host_set_entries(struct gdhcpd_widgets *widgets)
+void create_host_set_entries(struct w *widgets)
 {
     GtkWidget *frame;
     GtkWidget *table;
