@@ -27,7 +27,7 @@
 #include "clear_leases.h"
 
 
-void create_lease_tab(struct gdhcpd_widgets *widgets)
+void create_lease_tab(struct w *widgets)
 {
     /* Create the leases textview in a scrolled window */
     GtkWidget *leases_hbox, *leases_scrolled_window;
