@@ -23,7 +23,7 @@
 #include <string.h>
 #include "widgets.h"
 #include "gettext.h"
-#include "locate_icons.h" /* FIXME .. change name */
+#include "locate_icons.h"
 #include "activate_button_clicked.h"
 #include "deactivate_button_clicked.h"
 #include "reread_button_clicked.h"
@@ -31,9 +31,11 @@
 #include "show_help.h"
 #include "credits_window.h"
 #include "set_dhcpd_version.h"
+#include "loadbalance_window.h"
 
 
-void create_main_window(struct gdhcpd_widgets *widgets)
+
+void create_main_window(struct w *widgets)
 {
     gchar *info, *pixmap_directory;
     GtkCellRenderer *pixbuf_cell_renderer;
@@ -42,7 +44,7 @@ void create_main_window(struct gdhcpd_widgets *widgets)
     /* Create the main window */    
     widgets->main_window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
     gtk_window_set_position(GTK_WINDOW (widgets->main_window), GTK_WIN_POS_CENTER);
-    gtk_widget_set_size_request(widgets->main_window, 630, 450);
+    gtk_widget_set_size_request(widgets->main_window, 700, 500);
 
     /* Set window information */
     info = g_strdup_printf("GDHCPD %s", VERSION);
@@ -124,6 +126,21 @@ void create_main_window(struct gdhcpd_widgets *widgets)
     g_signal_connect_swapped(G_OBJECT(settings_button), "clicked", 
                              G_CALLBACK(show_settings_window), widgets);
 
+
+    /* Loadbalance button */
+    GtkWidget *toolbar_icon_loadbalance = gtk_image_new_from_stock("gtk-convert", 
+                                  gtk_toolbar_get_icon_size(GTK_TOOLBAR(main_toolbar)));
+    GtkWidget *loadbalance_button = gtk_toolbar_append_element(GTK_TOOLBAR(main_toolbar),
+                                                          GTK_TOOLBAR_CHILD_BUTTON,
+							  NULL, _("Loadbalance"), 
+							  NULL, NULL,
+							  toolbar_icon_loadbalance, NULL, NULL);
+    g_signal_connect_swapped(G_OBJECT(loadbalance_button), "clicked", 
+                             G_CALLBACK(show_loadbalance_window), widgets);
+
+
+
+
     /* Help button */
     GtkWidget *toolbar_icon_help = gtk_image_new_from_stock("gtk-help", 
                                    gtk_toolbar_get_icon_size(GTK_TOOLBAR(main_toolbar)));
@@ -137,7 +154,7 @@ void create_main_window(struct gdhcpd_widgets *widgets)
 
 
     /* Credits button */
-    GtkWidget *toolbar_icon_credits = gtk_image_new_from_stock("gtk-index", 
+    GtkWidget *toolbar_icon_credits = gtk_image_new_from_stock("gtk-justify-center", 
                                       gtk_toolbar_get_icon_size(GTK_TOOLBAR(main_toolbar)));
     GtkWidget *credits_button = gtk_toolbar_append_element(GTK_TOOLBAR(main_toolbar),
                                                           GTK_TOOLBAR_CHILD_BUTTON,
@@ -166,6 +183,7 @@ void create_main_window(struct gdhcpd_widgets *widgets)
     widgets->notebook_vbox1 = gtk_vbox_new(FALSE, 0);
     widgets->notebook_vbox2 = gtk_vbox_new(FALSE, 0);
     widgets->notebook_vbox3 = gtk_vbox_new(FALSE, 0);
+    widgets->notebook_vbox4 = gtk_vbox_new(FALSE, 0);
 
     GtkWidget *main_notebook = gtk_notebook_new();
     gtk_box_pack_start(GTK_BOX(notebook_vbox), main_notebook, TRUE, TRUE, 0);
@@ -175,10 +193,12 @@ void create_main_window(struct gdhcpd_widgets *widgets)
     GtkWidget *scope_label = gtk_label_new(_("Scopes"));
     GtkWidget *single_hosts_label = gtk_label_new(_("Single hosts"));
     GtkWidget *leases_label = gtk_label_new(_("Leases"));
+    GtkWidget *verify_label = gtk_label_new(_("Verify"));
 
     gtk_notebook_insert_page(GTK_NOTEBOOK(main_notebook), widgets->notebook_vbox1, scope_label, 0);
     gtk_notebook_insert_page(GTK_NOTEBOOK(main_notebook), widgets->notebook_vbox2, single_hosts_label, 1);
     gtk_notebook_insert_page(GTK_NOTEBOOK(main_notebook), widgets->notebook_vbox3, leases_label, 2);
+    gtk_notebook_insert_page(GTK_NOTEBOOK(main_notebook), widgets->notebook_vbox4, verify_label, 3);
 
     /* Set version and status labels */
     widgets->dhcpd_version_label = gtk_label_new(_("Information: cant read version"));
