@@ -2,9 +2,9 @@
 #ifndef GDHCPD_create_scope_set_entries_H
 #   define GDHCPD_create_scope_set_entries_H
 
-extern struct gdhcpd_widgets *widgets;
+extern struct w *widgets;
 
-void create_scope_set_entries(struct gdhcpd_widgets *widgets);
+void create_scope_set_entries(struct w *widgets);
 
 GtkWidget *make_scope_entry_with_label(GtkTable *table,
 				 const gchar *label_text,
