@@ -65,7 +65,7 @@ void show_credits()
   "\n-------------------------------------------------------------------------\n",
   _("The ISC DHCPD developers.\n"),
   "Sebastian Schoss ", _("for")," www.gadmintools.org\n",
-  "Bjorn Lindner ", _("for the program icons.\n"),
+  "Bjoern Lindner ", _("for the program icons.\n"),
   "Daniel Baumann <daniel.baumann@panthera-systems.net>\n", 
   _("for maintaining the Debian package."),
   "\n\n",
