@@ -24,12 +24,14 @@
 #include <string.h>
 #include "widgets.h"
 #include "gettext.h"
-#include "commands.h"
+#include "functions.h"
 #include "show_info.h"
 
 extern int activated;
 
-void deactivate_button_clicked(struct gdhcpd_widgets *widgets)
+
+
+void deactivate_button_clicked(struct w *widgets)
 {
     gchar *stop, *info;
 
