@@ -1,8 +1,8 @@
 #ifndef GDHCPD_deactivate_button_clicked_H
 #   define GDHCPD_deactivate_button_clicked_H
 
-extern struct gdhcpd_widgets *widgets;
+extern struct w *widgets;
 
-void deactivate_button_clicked(struct gdhcpd_widgets *widgets);
+void deactivate_button_clicked(struct w *widgets);
 
 #endif
