@@ -37,7 +37,7 @@ extern int MAX_CONF_LINE;
 #include "reread_conf.h"
 
 
-void delete_host(struct gdhcpd_widgets *widgets)
+void delete_host(struct w *widgets)
 {
     FILE *fp;
     long conf_size=0;
@@ -72,6 +72,7 @@ void delete_host(struct gdhcpd_widgets *widgets)
 
     line = allocate(conf_size+1);
 
+    if( conf_size > 1 )
     while(fgets(line, conf_size, fp)!=NULL)
     {
 	if( ( !strcmp(line, scope_line1) || !strcmp(line, scope_line2) 
