@@ -31,7 +31,7 @@
 #include "reread_conf.h"
 
 
-void delete_host_from_btn(struct gdhcpd_widgets *widgets)
+void delete_host_from_btn(struct w *widgets)
 {
     delete_host(widgets);
     populate_host_treeview(widgets);
