@@ -32,26 +32,58 @@
 #include "show_info.h"
 #include "set_num_ranges.h"
 #include "reread_conf.h"
+#include "failover_functions.h"
+
+extern char global_netmask[1024];
+extern char global_subnet[1024];
+extern char global_nic[1024];
 
 extern char DHCPD_CONF_BUF[1024];
 extern int MAX_CONF_LINE;
 extern int del_row_num;
+extern int num_ranges;
+extern int activated;
 
 
 
-void delete_range(struct gdhcpd_widgets *widgets)
+void delete_range(struct w *widgets)
 {
     FILE *fp;
     long conf_size=0;
     int found_scope=0, range_deleted=0;
+    int have_failover = 0;
     char *line;
     char *new_conf;
     char *line_from;
     char *line_to;
     gchar *info;
 
-    line_from = allocate(MAX_CONF_LINE+1);
-    line_to = allocate(MAX_CONF_LINE+1);
+    /* If this subnet contains a failover pool the last range
+       cant be deleted or the server goes offline */
+    gchar *nic = g_strdup_printf("%s", global_nic);
+    gchar *subnet = g_strdup_printf("%s", global_subnet);
+    gchar *netmask = g_strdup_printf("%s", global_netmask);
+
+    have_failover = failover_exists(nic, subnet, netmask);
+
+    g_free(nic);
+    g_free(subnet);
+    g_free(netmask);
+    
+    if( activated && have_failover && num_ranges < 2 )
+    {
+        info = g_strconcat(
+        _("This subnet contains a loadbalance configuration and the server is activated.\n"),
+        _("Atleast one range must exist in this situation or the server will be deactivated.\n\n"),
+
+        _("If this is what you want then deactivate the server before deleting the range.\n"),
+        _("You can also add another range before deleting this one.\n"),
+        NULL);
+        show_info(info);
+        g_free(info);
+	return;
+    }
+
 
     /* 3 different styles ...\n{ or ...{ or ... { */
     gchar *scope_line1 = g_strdup_printf("subnet %s netmask %s\n", global_subnet, global_netmask);
@@ -59,18 +91,15 @@ void delete_range(struct gdhcpd_widgets *widgets)
     gchar *scope_line3 = g_strdup_printf("subnet %s netmask %s {\n", global_subnet, global_netmask);
     gchar *nic_line = g_strdup_printf("interface %s;\n", global_nic);
 
-    gpointer range_from_arr = g_ptr_array_index(widgets->ranges_from_entry_array, 
-									  del_row_num);
-    gpointer range_to_arr = g_ptr_array_index(widgets->ranges_to_entry_array, 
-									  del_row_num);
+    gpointer range_from_arr = g_ptr_array_index(widgets->ranges_from_entry_array, del_row_num);
+    gpointer range_to_arr = g_ptr_array_index(widgets->ranges_to_entry_array, del_row_num);
 
     if( range_from_arr==NULL || range_to_arr==NULL )
     {
-       printf("Pointer arrays are NULL in delete_range\n");
-       info = g_strdup_printf(_("Pointer array value is NULL, range not deleted\n"));
-       show_info(info);
-       g_free(info);
-       return;
+        info = g_strdup_printf(_("Pointer array value is NULL, range not deleted\n"));
+        show_info(info);
+        g_free(info);
+        return;
     }
     
     G_CONST_RETURN gchar *range_from = gtk_entry_get_text(GTK_ENTRY((gpointer)range_from_arr));
@@ -97,6 +126,7 @@ void delete_range(struct gdhcpd_widgets *widgets)
     new_conf = allocate(conf_size+1);
     line = allocate(conf_size+1);
 
+    if( conf_size > 1 )
     while(fgets(line, conf_size, fp)!=NULL)
     {
 	if( ( strstr(line, scope_line1) || strstr(line, scope_line2) 
@@ -108,6 +138,10 @@ void delete_range(struct gdhcpd_widgets *widgets)
 	    {
 		strcat(new_conf, line);
 
+		/* Break if we find another subnet */
+		if( strstr(line, "subnet") && strstr(line, "netmask") && ! strstr(line, "#") )
+		  break;
+
 		if( strstr(line, nic_line) && ! strstr(line, "#") )
 		{
 		    found_scope = 1;
@@ -122,19 +156,25 @@ void delete_range(struct gdhcpd_widgets *widgets)
 	  break;
     }
 
+
+    line_from = allocate(MAX_CONF_LINE+1);
+    line_to = allocate(MAX_CONF_LINE+1);
+
+
     if( found_scope )
     {
+	if( conf_size > 1 )
 	while(fgets(line, conf_size, fp)!=NULL)
 	{
 	    if( strstr(line, "range") && ! strstr(line, "#") )
 	    {
-	        if( ! range_deleted )
+	        if( ! range_deleted && strlen(line) < MAX_CONF_LINE )
 		{
 		    sscanf(line, "%*s %s %s", line_from, line_to);
 		    line_to[strlen(line_to)-1]='\0';
 
 		    if( ! strcmp(line_from, range_from) && ! strcmp(line_to, range_to) )
-		      range_deleted=1;
+		      range_deleted = 1;
 		    else
 		      strcat(new_conf, line);
 		}
@@ -145,9 +185,12 @@ void delete_range(struct gdhcpd_widgets *widgets)
 	      strcat(new_conf, line);
 	}
     }
-
     fclose(fp);
+    free(line_from);
+    free(line_to);
 
+
+    /* Write the new configuration */
     if((fp=fopen(DHCPD_CONF_BUF, "w+"))==NULL)
     {
 	printf("Couldnt find: %s\n", DHCPD_CONF_BUF);
@@ -161,8 +204,6 @@ void delete_range(struct gdhcpd_widgets *widgets)
 
     free(new_conf);
     free(line);
-    free(line_from);
-    free(line_to);
 
     g_free(scope_line1);
     g_free(scope_line2);
