@@ -27,8 +27,8 @@
 #include "gettext.h"
 #include "widgets.h"
 #include "locate_icons.h"
-#include "commands.h"
-
+#include "allocate.h"
+#include "functions.h"
 
 /* Use as externs */
 char global_netmask[1024]="";
@@ -39,9 +39,10 @@ char global_ipaddr[1024]="";
 char global_hwaddr[1024]="";
 char global_hostname[1024]="";
 
-int del_row_num;
-int num_ranges;
-int activated;
+int del_row_num=0;
+int num_ranges=0;
+int activated=0;
+int info_window_exit_main=0;
 
 int MAX_CONF_LINE=1024;
 int MAX_READ_POPEN=8192;
@@ -49,12 +50,11 @@ int MAX_READ_POPEN=8192;
 char LEASE_FILE_BUF[1024]="";
 char DHCPD_CONF_BUF[1024]="";
 
-
-#include "allocate.h"
 #include "create_main_window.h"
 #include "create_scope_tab.h"
 #include "create_host_tab.h"
 #include "create_lease_tab.h"
+#include "create_verify_tab.h"
 #include "populate_scope_treeview.h"
 #include "populate_scope_settings.h"
 #include "select_first_scope.h"
@@ -75,6 +75,7 @@ int main(int argc, char *argv[])
 {
     FILE *fp;
     char *command, *info;
+    int i=0;
 
 #ifdef ENABLE_NLS
     bindtextdomain(GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR);
@@ -87,18 +88,31 @@ int main(int argc, char *argv[])
 
     wid *widgets = g_malloc (sizeof (wid));
 
+
+    /* Non root usage */
     if( ! getuid() == 0 )
     {
-        printf("You must be root to run: %s\n", PACKAGE);
+	/* For setting a different exit method in the info window */
+	info_window_exit_main = 1;
+
         info = g_strdup_printf("You must be root to run: %s\nThis window will close in 10 seconds.\n", PACKAGE);
         show_info(info);
-				
-        while(gtk_events_pending())
-              gtk_main_iteration();
-        sleep(10);
-						     
         g_free(info);
-	g_free(widgets); /* The array has not yet been allocated */
+
+	/* Users can close the info window earlier then the timeout */
+	for(i=0; i<10; i++)
+	{
+    	    while(gtk_events_pending())
+                  gtk_main_iteration();
+
+	    /* Set when close info window is clicked */
+	    if( info_window_exit_main == 2 )
+	      break;
+
+    	    usleep(100000*10);
+    	}
+
+	g_free(widgets); /* The g_ptr_array has not yet been allocated */
 	return 0;
     }
 
@@ -167,6 +181,7 @@ int main(int argc, char *argv[])
 
     create_lease_tab(widgets);
 
+    create_verify_tab(widgets);
 
     /* Pointer arrays for the dynamic range widgets */
     widgets->ranges_hbox_array = g_ptr_array_new();
