@@ -2,7 +2,7 @@
 #ifndef HAVE_gdhcpd_H
 #   define HAVE_gdhcpd_H
 
-extern struct gdhcpd_widgets *widgets;
+extern struct w *widgets;
 
 int main(int argc, char *argv[]);
 
