@@ -24,7 +24,6 @@
 #include <stdlib.h>
 #include "widgets.h"
 #include "gettext.h"
-
 #include "allocate.h"
 
 
@@ -38,8 +37,9 @@ extern char DHCPD_CONF_BUF[1024];
 char * get_ranges_from_current_scope()
 {
     FILE *fp;
-    long conf_size=0;
-    int found_scope=0, i=0;
+    long conf_size = 0;
+    int found_scope = 0;
+    int found_pool = 0;
     char *line, *retval=NULL;
 
     gchar *scope_line1 = g_strdup_printf("subnet %s netmask %s\n", global_subnet, global_netmask);
@@ -61,6 +61,7 @@ char * get_ranges_from_current_scope()
     /* Freed in the calling function */
     retval = allocate(conf_size+1);
 
+    if( conf_size > 1 )
     while(fgets(line, conf_size, fp)!=NULL)
     {
 	if( ( strstr(line, scope_line1) || strstr(line, scope_line2) 
@@ -70,7 +71,7 @@ char * get_ranges_from_current_scope()
 	    {
 		if( strstr(line, nic_line) && ! strstr(line, "#") )
 		{
-		    found_scope=1;
+		    found_scope = 1;
 		    break;
 		}
 	    }
@@ -79,18 +80,36 @@ char * get_ranges_from_current_scope()
 	  break;
     }
 
-    if( found_scope )
+
+    /* If it has a pool declaration for the ranges it must also be added */
+    if( found_scope && conf_size > 1 )
     {
-	i=0;	
 	while(fgets(line, conf_size, fp)!=NULL)
 	{
-	    if( strstr(line, "}") && strlen(line)<3 )
+	    if( strstr(line, "}") && strlen(line) < 3 )
 	      break;
-	
-	    if( strstr(line, "range ") && ! strstr(line, "#") )
+
+	    /* Gather failover pool ranges */
+	    if( strstr(line, "pool {") )
 	    {
+		found_pool = 1;
 		strcat(retval, line);
+
+		while(fgets(line, conf_size, fp)!=NULL)
+		{
+		    if( strstr(line, "}") && strlen(line) < 3 )
+			break;
+	    
+		    strcat(retval, line);
+		}
 	    }
+	    
+	    if( found_pool )
+	      break;
+
+	    /* Gather normal ranges */	    	
+	    if( strstr(line, "range ") && ! strstr(line, "#") )
+	      strcat(retval, line);
 	}
     }
     fclose(fp);
