@@ -20,8 +20,8 @@
 #ifndef load_settings_H
 #   define load_settings_H
 
-extern struct gdhcpd_widgets *widgets;
+extern struct w *widgets;
 
-void load_settings(struct gdhcpd_widgets *widgets);
+void load_settings(struct w *widgets);
 
 #endif
