@@ -29,7 +29,7 @@
 extern char LEASE_FILE_BUF[1024];
 
 
-void populate_leases(struct gdhcpd_widgets *widgets)
+void populate_leases(struct w *widgets)
 {
     FILE *fp;
     long conf_size=0;
@@ -41,7 +41,6 @@ void populate_leases(struct gdhcpd_widgets *widgets)
     
     if((fp=fopen(LEASE_FILE_BUF, "r"))==NULL)
     {
-        printf("Couldnt find: %s\n", LEASE_FILE_BUF);
         return;
     }
     fseek(fp, 0, SEEK_END);
@@ -51,10 +50,10 @@ void populate_leases(struct gdhcpd_widgets *widgets)
     line = allocate(conf_size+1);
     buffy = allocate(conf_size+1);
 
+    if( conf_size > 1 )
     while(fgets(line, conf_size, fp)!=NULL)
-    {
-	strcat(buffy, line);
-    }
+      strcat(buffy, line);
+
     fclose(fp);
     free(line);
 
