@@ -1,9 +1,9 @@
 #ifndef GDHCPD_populate_ranges_H
 #   define GDHCPD_populate_ranges_H
 
-extern struct gdhcpd_widgets *widgets;
+extern struct w *widgets;
 
-void populate_ranges(struct gdhcpd_widgets *widgets, 
+void populate_ranges(struct w *widgets, 
                                     	    gchar *nic, 
                                             gchar *subnet, 
 					    gchar *netmask);
