@@ -25,7 +25,7 @@
 #include "widgets.h"
 #include "gettext.h"
 #include "allocate.h"
-#include "commands.h"
+#include "functions.h"
 #include "create_scope_set_entries.h"
 
 
@@ -36,7 +36,8 @@ extern char global_nic[1024];
 extern char DHCPD_CONF_BUF[1024];
 
 
-void populate_scope_settings(struct gdhcpd_widgets *widgets)
+
+void populate_scope_settings(struct w *widgets)
 {
     FILE *fp;
     gchar *utf8=NULL;
@@ -68,13 +69,16 @@ void populate_scope_settings(struct gdhcpd_widgets *widgets)
     utf8 = g_locale_to_utf8((char *)global_netmask, strlen(global_netmask), NULL, NULL, NULL);
     gtk_entry_set_text(GTK_ENTRY(widgets->scope_set_entry[2]), utf8);
 
-
-    buffy = allocate(1024);
-
     /* Insert the values from the scope */
     if((fp=fopen(DHCPD_CONF_BUF, "r"))==NULL)
     {
-        printf("Couldnt find: %s\n", DHCPD_CONF_BUF);
+	g_free(scope_line1);
+	g_free(scope_line2);
+	g_free(scope_line3);
+	g_free(nic_line);
+
+	if( utf8!=NULL )
+          g_free(utf8);
         return;
     }
     fseek(fp, 0, SEEK_END);
@@ -82,7 +86,9 @@ void populate_scope_settings(struct gdhcpd_widgets *widgets)
     rewind(fp);
 
     line = allocate(conf_size+1);
+    buffy = allocate(1024);
 
+    if( conf_size > 1 )
     while(fgets(line, conf_size, fp)!=NULL)
     {
 	if( (strstr(line, scope_line1) || strstr(line, scope_line2) 
@@ -92,7 +98,7 @@ void populate_scope_settings(struct gdhcpd_widgets *widgets)
 	    {
 		if( strstr(line, nic_line) && ! strstr(line, "#") )
 		{
-		    found_scope=1;
+		    found_scope = 1;
 		    break;
 		}
 	    }
@@ -101,10 +107,19 @@ void populate_scope_settings(struct gdhcpd_widgets *widgets)
 	  break;
     }
 
-    if( found_scope )
+
+    /* The scope is found, list the values */
+    if( found_scope && conf_size > 1 )
     while(fgets(line, conf_size, fp)!=NULL)
     {
-	/* Break at scope end */
+	/* Scroll past any failover pools */
+	if( strstr(line, "pool") && strstr(line, "{") && ! strstr(line, "#") )
+	{
+	    while(fgets(line, conf_size, fp)!=NULL)
+	    if( strstr(line, "}") && ! strstr(line, "#") )
+	      break;
+	}
+	else /* Break at scope end */
 	if( strstr(line, "}") && ! strstr(line, "#") )
 	  break;
 
@@ -297,6 +312,11 @@ void populate_scope_settings(struct gdhcpd_widgets *widgets)
     free(line);
     free(buffy);
 
+    g_free(scope_line1);
+    g_free(scope_line2);
+    g_free(scope_line3);
+    g_free(nic_line);
+
     if( utf8!=NULL )
       g_free(utf8);
 
