@@ -25,12 +25,14 @@
 #include "widgets.h"
 #include "gettext.h"
 #include "allocate.h"
+#include "failover_functions.h"
 
 extern char DHCPD_CONF_BUF[1024];
 extern int MAX_CONF_LINE;
 
 
-void populate_scope_treeview(struct gdhcpd_widgets *widgets)
+
+void populate_scope_treeview(struct w *widgets)
 {
     FILE *fp;
     GtkTreeIter iter;
@@ -43,12 +45,12 @@ void populate_scope_treeview(struct gdhcpd_widgets *widgets)
     char *nic;
     char *subnet;
     char *netmask;
+    gchar *failover;
 
     gtk_list_store_clear(widgets->scope_store);
 
     if((fp=fopen(DHCPD_CONF_BUF, "r"))==NULL)
     {
-       printf("Couldnt find: %s\n", DHCPD_CONF_BUF);
        return;
     }
     fseek(fp, 0, SEEK_END);
@@ -56,13 +58,11 @@ void populate_scope_treeview(struct gdhcpd_widgets *widgets)
     rewind(fp);
 
     line = allocate(conf_size+1);
-
     nic = allocate(MAX_CONF_LINE);
-
     subnet = allocate(MAX_CONF_LINE);
-
     netmask = allocate(MAX_CONF_LINE);
-    
+
+    if( conf_size > 1 )    
     while(fgets(line, conf_size, fp)!=NULL)
     {
 	if( strstr(line, "subnet") && strstr(line, "netmask") && ! strstr(line, "#") )
@@ -70,17 +70,15 @@ void populate_scope_treeview(struct gdhcpd_widgets *widgets)
 	    sscanf(line, "%*s %s %*s %s", subnet, netmask);	    
 	    while(fgets(line, conf_size, fp)!=NULL)
 	    {
-		if( strstr(line, "#") )
-		{
-		   break;
-		}
-		
 		if( strstr(line, "interface") && ! strstr(line, "#") )
 		{
 		    sscanf(line, "%*s %s", nic);
 		    gtk_list_store_append(GTK_LIST_STORE(widgets->scope_store), &iter);
+
+		    if( nic[strlen(nic)-1]==';')
+		      nic[strlen(nic)-1]='\0';
 		    
-		    utf8 = g_locale_to_utf8(nic, strlen(nic)-1, NULL, NULL, NULL);
+		    utf8 = g_locale_to_utf8(nic, strlen(nic), NULL, NULL, NULL);
 		    gtk_list_store_set(GTK_LIST_STORE(widgets->scope_store), &iter, 0, utf8, -1);
 		    
 		    utf8 = g_locale_to_utf8(subnet, strlen(subnet), NULL, NULL, NULL);
@@ -88,9 +86,17 @@ void populate_scope_treeview(struct gdhcpd_widgets *widgets)
 		    
 		    if( strstr(netmask, "{") )
 		      netmask[strlen(netmask)-1]='\0';
+
 		    utf8 = g_locale_to_utf8(netmask, strlen(netmask), NULL, NULL, NULL);
 		    gtk_list_store_set(GTK_LIST_STORE(widgets->scope_store), &iter, 2, utf8, -1);
-		    set_cursorpath=1;
+		    set_cursorpath = 1;
+		    
+		    /* Get the failover peer if any */
+		    failover = get_failover(nic, subnet, netmask, "peer address");
+		    utf8 = g_locale_to_utf8(failover, strlen(failover), NULL, NULL, NULL);
+		    gtk_list_store_set(GTK_LIST_STORE(widgets->scope_store), &iter, 3, utf8, -1);
+		    g_free(failover);
+
 		    break;
 		}
 	    }
