@@ -26,7 +26,7 @@
 #include "reread_conf.h"
 
 
-void reread_button_clicked(struct gdhcpd_widgets *widgets)
+void reread_button_clicked(struct w *widgets)
 {
     reread_conf();
 }
