@@ -24,12 +24,13 @@
 #include <string.h>
 #include "widgets.h"
 #include "gettext.h"
-#include "commands.h"
+#include "functions.h"
 
 extern int activated;
 extern char DHCPD_CONF_BUF[1024];
 
 
+
 void reread_conf()
 {
     /* It doesnt restart/reread with a HUP, no problem */
