@@ -30,7 +30,7 @@ extern char global_ipaddr[1024];
 extern char global_hostname[1024];
 
 
-void select_first_host(struct gdhcpd_widgets *widgets)
+void select_first_host(struct w *widgets)
 {
     GtkTreePath *path;
     GtkTreeIter iter;
