@@ -29,7 +29,7 @@ extern char global_subnet[1024];
 extern char global_nic[1024];
 
 
-void select_first_scope(struct gdhcpd_widgets *widgets)
+void select_first_scope(struct w *widgets)
 {
     GtkTreePath *path;
     GtkTreeIter iter;
