@@ -27,19 +27,26 @@
 #include "allocate.h"
 #include "set_num_ranges.h"
 
+extern char global_netmask[1024];
+extern char global_subnet[1024];
+extern char global_nic[1024];
+
 extern int num_ranges;
 extern char DHCPD_CONF_BUF[1024];
 
 
+
 void set_num_ranges(gchar *nic, gchar *subnet, gchar *netmask)
 {
     FILE *fp;
     long conf_size=0;
     int found_scope=0;
     char *line;
-    
-    /* Global values */
-    num_ranges=0; 
+
+    /* Set some global values */
+    num_ranges = 0;
+
+    // FIXME: source and destination overlap
     sprintf(global_subnet, "%s", subnet);
     sprintf(global_netmask, "%s", netmask);
     sprintf(global_nic, "%s", nic);
@@ -51,15 +58,19 @@ void set_num_ranges(gchar *nic, gchar *subnet, gchar *netmask)
 
     if((fp=fopen(DHCPD_CONF_BUF, "r"))==NULL)
     {
-       printf("set_num_ranges, cant open: %s\n", DHCPD_CONF_BUF);
-       return;
+	g_free(scope_line1);
+	g_free(scope_line2);
+	g_free(scope_line3);
+	g_free(nic_line);
+        return;
     }
     fseek(fp, 0, SEEK_END);
     conf_size = ftell(fp);
     rewind(fp);
 
     line = allocate(conf_size+1);
-    
+
+    if( conf_size > 1 )    
     while(fgets(line, conf_size, fp)!=NULL)
     {
 	if( ( strstr(line, scope_line1) || strstr(line, scope_line2) 
@@ -69,7 +80,7 @@ void set_num_ranges(gchar *nic, gchar *subnet, gchar *netmask)
 	    {
 		if( strstr(line, nic_line) && ! strstr(line, "#") )
 		{
-		    found_scope=1;
+		    found_scope = 1;
 		    break;
 		}
 	    }
@@ -78,21 +89,30 @@ void set_num_ranges(gchar *nic, gchar *subnet, gchar *netmask)
 	  break;
     }
 
-    if( found_scope )
+
+    if( found_scope && conf_size > 1 )
     {
 	while(fgets(line, conf_size, fp)!=NULL)
 	{
-	    if( strstr(line, "}") && strlen(line)<3 )
+	    /* Break at the next subnet declaration if any */
+	    if( strstr(line, "subnet") && strstr(line, "}") )
 	      break;
+
+	    /* Scroll past any failover peers */
+	    if( strstr(line, "failover peer") && strstr(line, "}") && ! strstr(line, "#") )
+	    {
+		while(fgets(line, conf_size, fp)!=NULL)
+		  if( strstr(line, "}") && strlen(line)<3 )
+	            break;
+	    }
 	
 	    if( strstr(line, "range ") && ! strstr(line, "#") )
 	      num_ranges++;
 	}
     }
-
     fclose(fp);
-
     free(line);
+
     g_free(scope_line1);
     g_free(scope_line2);
     g_free(scope_line3);
