@@ -26,7 +26,7 @@
 #include "show_info.h"
 
 
-void show_help(struct gdhcpd_widgets *widgets)
+void show_help(struct w *widgets)
 {
     gchar *help;
     help = g_strconcat(
@@ -73,6 +73,21 @@ void show_help(struct gdhcpd_widgets *widgets)
     _("4. Current usage:\n"),
     _("	The leases tab shows currently active clients and what values such as the\n"),
     _("	IP-addresses, subnet masks and hardware addresses they currently use.\n"),
+
+    "\n\n",
+
+    _("5. Loadbalancing and failover setups:\n"),
+    _("	First setup a basic scope and atleast one range.\n"),
+    _("	Press the loadbalance button to add a loadbalancer for the selected subnet.\n"),
+    _("	Standard values are automatically filled in and are most likely as they should be.\n"),
+    _("	A unique loadbalance name must be specified and also this servers address.\n"),
+    _("	Select primary or secondary server type.\n"),
+    _("	You also need to specify a remote server address on the same subnet as this server.\n"),
+    _("	Hit apply and youre done.\n\n"),
+
+    _("	Change the loadbalancer by altering its settings and pressing apply.\n"),
+    _("	\n"),
+
     "\n", NULL);
 
     show_info(help);
