@@ -24,8 +24,18 @@
 #include "widgets.h"
 #include "gettext.h"
 
+extern int info_window_exit_main;
 
-void show_info(char *content)
+
+void info_set_exit(gchar *content)
+{
+    /* 2 means break the non-root wait loop in main() */
+    info_window_exit_main = 2;
+}
+
+
+
+void show_info(gchar *content)
 {
     gchar *utf8=NULL;
     GtkTextBuffer *text_buffer;
@@ -65,21 +75,38 @@ void show_info(char *content)
 				      GTK_POLICY_AUTOMATIC, GTK_POLICY_ALWAYS);
 
     info_viewport = gtk_viewport_new(NULL, NULL);
-    gtk_container_add (GTK_CONTAINER (scrolled_info_window), info_viewport);
+    gtk_container_add(GTK_CONTAINER(scrolled_info_window), info_viewport);
 
     info_textview = gtk_text_view_new();
-    gtk_container_add (GTK_CONTAINER (info_viewport), info_textview);
-    gtk_text_view_set_wrap_mode(info_textview, GTK_WRAP_WORD);
+    gtk_container_add(GTK_CONTAINER(info_viewport), info_textview);
+
+    gtk_text_view_set_wrap_mode(GTK_TEXT_VIEW(info_textview), GTK_WRAP_WORD);
 
-    g_signal_connect(GTK_WINDOW(info_window), "delete_event", 
-		     G_CALLBACK (gtk_widget_destroy), NULL);
 
     GtkWidget *close_info_button = gtk_button_new_from_stock(GTK_STOCK_CLOSE);
     gtk_box_pack_start(GTK_BOX(info_vbox), close_info_button, FALSE, TRUE, 0);
 
-    g_signal_connect_swapped((gpointer) close_info_button, "clicked",
-                                     G_CALLBACK (gtk_widget_destroy),
-                                              GTK_OBJECT (info_window));
+
+    /* Used with main() and closing the non-root timer */
+    if( info_window_exit_main )
+    {
+	g_signal_connect_swapped((gpointer) close_info_button, "clicked",
+                         G_CALLBACK(info_set_exit), info_window);
+
+	g_signal_connect(GTK_WINDOW(info_window), "delete_event", 
+                         GTK_SIGNAL_FUNC(info_set_exit), info_window);
+    }
+
+    /* Regular close info window hookups */
+    if( ! info_window_exit_main )
+    {
+	g_signal_connect_swapped((gpointer) close_info_button, "clicked",
+                              G_CALLBACK(gtk_widget_destroy), GTK_OBJECT(info_window));
+
+	g_signal_connect(GTK_WINDOW(info_window), "delete_event", 
+		     G_CALLBACK(gtk_widget_destroy), NULL);
+    }
+
 
     text_buffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(info_textview));
     utf8 = g_locale_to_utf8(content, strlen(content), NULL, NULL, NULL);
