@@ -34,7 +34,7 @@ extern int activated;
 
 
 
-int status_update(struct gdhcpd_widgets *widgets)
+int status_update(struct w *widgets)
 {
     struct sockaddr_in myaddr;
     int port=67; /* ipv4 */
