@@ -24,18 +24,23 @@
 #define NUM_SETTINGS_ENTRIES 2
 #define NUM_SETTINGS_COMBOS  5
 
+/* Number of widgets used in the loadbalancing window */
+#define NUM_LOADBALANCE_ENTRIES 10
+#define NUM_LOADBALANCE_COMBOS  5
+
 /* Number of entries used in the scope and host settings */
 #define NUM_SCOPE_SETTINGS 16
 #define NUM_HOST_SETTINGS  16
 
 
-typedef struct gdhcpd_widgets
+typedef struct w
 {
   GtkWidget *main_window;
   GtkWidget *main_vbox;
   GtkWidget *notebook_vbox1;
   GtkWidget *notebook_vbox2;
   GtkWidget *notebook_vbox3;
+  GtkWidget *notebook_vbox4;
   GtkWidget *onoff_label;
   GtkWidget *dhcpd_version_label;
   GtkWidget *scope_treeview;
@@ -87,9 +92,18 @@ typedef struct gdhcpd_widgets
   GtkWidget *settings_entry[NUM_SETTINGS_ENTRIES];
   GtkWidget *settings_combo[NUM_SETTINGS_COMBOS];
 
+  /* Loadbalancing window */
+  GtkWidget *loadbalance_window;
+  GtkWidget *loadbalance_entry[NUM_LOADBALANCE_ENTRIES];
+  GtkWidget *loadbalance_combo[NUM_LOADBALANCE_COMBOS];
+
   /* Leases tab */
   GtkWidget *leases_textview;  
 
   GtkWidget *credits_window;
 
+  /* Verify tab */
+  GtkWidget *verify_textview;
+  GtkWidget *verify_run_cmd_entry;
+
 }wid;
